@@ -14,7 +14,7 @@ _moduleLogger = logging.getLogger("channel.text")
 
 class TextChannel(tp.ChannelTypeText):
 	"""
-	Look into implementing ChannelInterfaceMessages for rich text formatting
+	@todo Look into implementing ChannelInterfaceMessages for rich text formatting
 
 	@bug Stopped working on Maemo 4.1
 	"""
